# OpenPaymentMethodTypeFieldsType

The type of this field. 

## Enum

* `STRING` (value: `'string'`)

* `DATE` (value: `'date'`)

* `DATETIME` (value: `'datetime'`)

* `NUMBER` (value: `'number'`)

* `BOOLEAN` (value: `'boolean'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


